==> wiki3_4_4.zip: wiki3_4_4/plugin/attach/Attach.pm <==
############################################################
#
# եźդ뤿Υեɽޤ
# <pre>
# {{attach}}
# </pre>
# źդեϥեξ˰ɽޤ
# ƱեźդʣɽƤޤΤϤȤǤ
# nolistץĤȰɽԤޤ
# <pre>
# {{attach nolist}}
# </pre>
#
############################################################
package plugin::attach::Attach;
#use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# źեեɽ
#===========================================================
sub inline {
	my $self = shift;
	my $wiki = shift;
	my $option = shift;
	my $cgi  = $wiki->get_CGI;
	my $page = $cgi->param("page");
	
	if(defined($option) && $option ne "nolist"){
		if(!defined($self->{$page})){
			$self->{$page} = 1;
		} else {
			$self->{$page}++;
		}
	} else {
		$self->{$page} = undef;
	}
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"post\" enctype=\"multipart/form-data\">\n".
	          "  <input type=\"file\" name=\"file\">\n".
	          "  <input type=\"submit\" name=\"UPLOAD\" value=\" ź  \">\n".
	          "  <input type=\"hidden\" name=\"page\" value=\"". $cgi->escapeHTML($page)."\">\n".
	          "  <input type=\"hidden\" name=\"action\" value=\"ATTACH\">\n";
	
	if(defined($self->{$page})){
		$buf .= "  <input type=\"hidden\" name=\"count\" value=\"".$self->{$page}."\">\n";
	}
	
	$buf .= "</form>\n";

	return $buf;
}

1;

==> wiki3_5_0.zip: wiki3_5_0/plugin/attach/Attach.pm <==
############################################################
#
# եźդ뤿Υեɽޤ
# <pre>
# {{attach}}
# </pre>
# źդեϥեξ˰ɽޤ
# ƱեźդʣɽƤޤΤϤȤǤ
# nolistץĤȰɽԤޤ
# <pre>
# {{attach nolist}}
# </pre>
#
############################################################
package plugin::attach::Attach;
#use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# ץ饰μ̤֤ޤ
#===========================================================
sub type {
	return "html";
}

#===========================================================
# źեեɽ
#===========================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $option = shift;
	my $cgi    = $wiki->get_CGI;
	my $page   = $cgi->param("page");
	
	if(!defined($option) || $option ne "nolist"){
		if(!defined($self->{$page})){
			$self->{$page} = 1;
		} else {
			$self->{$page}++;
		}
	} else {
		$self->{$page} = undef;
	}
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"post\" enctype=\"multipart/form-data\">\n".
	          "  <input type=\"file\" name=\"file\">\n".
	          "  <input type=\"submit\" name=\"UPLOAD\" value=\" ź  \">\n".
	          "  <input type=\"hidden\" name=\"page\" value=\"". $cgi->escapeHTML($page)."\">\n".
	          "  <input type=\"hidden\" name=\"action\" value=\"ATTACH\">\n";
	
	if(defined($self->{$page})){
		$buf .= "  <input type=\"hidden\" name=\"count\" value=\"".$self->{$page}."\">\n";
	}
	
	$buf .= "</form>\n";

	return $buf;
}

1;
